#!/usr/bin/ruby
# simple ruby qmf console for the stress test

require 'optparse'
require 'qmf'

PACKAGE="com.redhat.stress_agent"
VALID_CHARS = ("a".."z").to_a + ("A".."Z").to_a + ("0".."9").to_a

def gen_rand_string(len)
     str = ""
     len.times  { str += VALID_CHARS[rand(VALID_CHARS.size-1)] }
     return str
end


def main()
    obj_type   = nil
    obj_id     = nil
    connections = 1
    iterations  = 1
    #num_objs   = nil
    #max_objs   = nil
    run_stress = false
    num_key_chars  = 8
    num_salt_chars = 8

    # setup cmd line options
    opts = OptionParser.new do |opts|
      opts.banner = "Usage: console.rb [options]"

      opts.on("-h", "--help", "Print this help message") do
         puts opts
         return
      end

      opts.on("-t", "--type [type]", "Specify type of object to retrieve") do |type|
         obj_type = type.downcase
      end

      opts.on("-i", "--id [id]", "Specify id of object to retrieve") do |id|
         obj_id = id.to_i
      end

      opts.on("-c", "--connections [num]", "Specify number of connections ") do |num|
         connections = num.to_i
      end

      opts.on("-x", "--iterations [num]", "Specify number of console iterations (for testing purposes)") do |num|
         iterations = num.to_i
      end

      #opts.on("-n", "--num [num]", "Specify number of objects to retrieve") do |num|
      #   num_objs = num.to_i
      #end

      #opts.on("-m", "--max [max]", "Specify max number of objects to retrieve (randomly generate)") do |max|
      #   max_objs = max.to_i
      #end

      opts.on("-s", "--stress", "Run stress test on appropriate objects") do
         run_stress = true
      end

      opts.on("-k", "--key-chars [num_chars]", "Number of stress test key characters") do |num_chars|
         num_key_chars = num_chars.to_i
      end

      opts.on("-a", "--salt-chars [num_chars]", "Number of stress test salt characters") do |num_chars|
         num_salt_chars = num_chars.to_i
      end

    end

    # parse cmd line
    begin
      opts.parse!(ARGV)
    rescue OptionParser::InvalidOption => e
      puts opts
      puts e.to_s
      return
    end

    #num_obs = rand(max_objs) unless max_objs.nil?

    if obj_type.nil?
       puts "must specify object type"
       puts opts
       return
    end

    qmf_settings      = Qmf::ConnectionSettings.new
    qmf_settings.host = 'localhost' 
    #qmf_settings.port = 

    connection = Qmf::Connection.new qmf_settings
    qmfc = Qmf::Console.new
    broker = qmfc.add_connection connection
    broker.wait_for_stable

    iterations.times {

      if !obj_id.nil?
        puts "Searching for object of class #{obj_type} in package #{PACKAGE} with id #{obj_id}"
        obj = qmfc.object(Qmf::Query.new(:class => obj_type), :package => PACKAGE,
                            :object_index => obj_id)
        puts "Object Retreived #{obj}"

        if run_stress && obj_type == "testobject"
            key  = gen_rand_string(num_key_chars)
            salt = gen_rand_string(num_salt_chars)
            password = obj.crypt(key, salt).passwd
        end

      else
        puts "Searching for objects of class #{obj_type} in packages #{PACKAGE}"
        worker_threads = []

        objs = qmfc.objects(Qmf::Query.new(:class => obj_type), :package => PACKAGE)

        puts "Got #{objs.size} objects"

        objs.each { |obj|
            puts "Object Retreived #{obj}"
            if run_stress && obj_type == "testobject"
                worker_threads.push Thread.new {
                  key  = gen_rand_string(num_key_chars)
                  salt = gen_rand_string(num_salt_chars)
                  password = obj.crypt(key, salt).passwd
                  puts "Generated password #{password} from #{key}-#{salt}"
                }
            end
         }
         worker_threads.each { |th| th.join }
      end
    }
end

begin
  Thread.abort_on_exception = true
  main()
rescue Exception => e
  puts "!!! Unhandled exception #{e}"
  puts e.backtrace
end
