# stress agent interface
#require 'activesupport' # use the inflector
require 'qmf'

class StressAgent < Qmf::AgentHandler
  def get_query(context, query, user_id)
    StressLogger.debug "got obj query for class #{query.class_name} w/ id #{query.object_id}"

    oquery = {:klass => query.class_name.camelize.constantize }
    oquery[:obj_id]  = query.object_id unless query.object_id.nil?
    # TODO add klass specific query attributes to oquery
    objs  = [@dispatch.get_objs(oquery)].flatten # get_objs may return a single obj or an array of them
    qobjs = []

    objs.each { |obj|
      obj.qmf_obj_id = @agent.alloc_object_id if obj.qmf_obj_id.nil?
      qobjs.push obj.to_qmf_obj @schema_classes.find{ |sc| sc.class_name == obj.klass.to_s }
    }


    qobjs.each { |qobj|
      StressLogger.debug "returning qmf obj #{qobj}"
      @agent.query_response(context, qobj)
    }
    @agent.query_complete(context)
  end

  def method_call(context, name, object_id, args, user_id)
    StressLogger.debug "invoking method:#{name} on obj_id:#{object_id}"
    @dispatch.invoke_method(object_id, name.interm, args)
    @agent.method_response(context, 0, "OK", args)
  end

  # set class which to handle requests
  def dispatch_to(target)
    @dispatch = target
  end

  def initialize(schema_file)
      StressLogger.debug "creating new agent"

      @settings = Qmf::ConnectionSettings.new
      @settings.host = "localhost"
      #@settings.port = port
      @connection = Qmf::Connection.new(@settings)
      @agent = Qmf::Agent.new(self)
 
      # parse schema, register classes that we provide, store in array
      @schema_classes = SchemaParser.parse :file => schema_file
      @schema_classes.each { |cl|
        @agent.register_class(cl)
      }
  end
 
  def mainloop
    Thread.abort_on_exception = true
    @agent.set_connection(@connection)
    sleep
  end
end
