# simple object bank for qmf usage 

class ManagedObject
   # klass      - class we're managing
   # id         - id of class we're managing
   # obj        - actual instance of klass we're managing
   # qmf_obj_id - qmf object id
   attr_accessor :klass, :id, :obj, :qmf_obj_id

   # convert object to specified Qmf::SchemaObjectClass instance
   def to_qmf_obj(qmf_klass)
       obj = Qmf::AgentObject.new(qmf_klass)
       qmf_klass.properties.each { |qprop|
          val = @obj.send(qprop.name.intern)
          obj[qprop.name.intern] = val unless val.nil?
       }
       obj.set_object_id(qmf_obj_id)
       return obj
   end

   def to_s
     "[ManagedObject #{object_id} #{klass}:#{id} #{obj}]"
   end

end

class ObjectBank

   def initialize
     StressLogger.debug "object bank initialized"
     @objects = []
   end

   def add_obj(obj)
     @objects.push obj unless obj.nil? || @objects.include?(obj)
     StressLogger.debug "adding #{obj} to bank"
   end

   def get_objs(args = {})
      klass  = args.has_key?(:klass)  ? args[:klass]  : nil
      obj_id = args.has_key?(:obj_id) ? args[:obj_id] : nil
      obj    = args.has_key?(:obj)    ? args[:obj]    : nil
      qmf_obj_id = args.has_key?(:qmf_obj_id) ? args[:qmf_obj_id] : nil
      StressLogger.debug "get obj called w/ klass:#{klass} obj_id:#{obj_id} obj:#{obj} qmf_obj_id:#{qmf_obj_id}"

      if !obj.nil?
        return @objects.find { |ob| ob == obj }
      elsif !klass.nil?
        return @objects.find_all { |ob| klass == klass }
      elsif !klass.nil? && !obj_id.nil?
        return @objects.find { |obj| obj.klass == klass && obj.id == obj_id }
      elsif !qmf_obj_id.nil?
        return @objects.find { |obj| obj.qmf_obj_id == qmf_obj_id }
      end
   end

   def invoke_method(qmf_obj_id, method, args)
      bkobj = get_objs :qmf_obj_id => qmf_obj_id
      bkobj.obj.send(method, args)
   end

end
