
#include "StressAgent.h"

#include "ArgsTestObjectCrypt.h"

#include <iostream>
#include <sstream>
#include <errno.h>
#include <cstring>

#ifndef _BSD_SOURCE
#define _BSD_SOURCE
#endif

#include <stdlib.h>

namespace _qmf = qmf::com::redhat::stress_agent;

Test::Test(ManagementAgent* agent, StressAgent *parent, int index)
{
    test = new _qmf::TestObject(agent, this, parent, index);
    agent->addObject(test);

    update();
}

Test::~Test()
{
    return;
}

void
Test::update()
{
    double ld_avg;

    getloadavg(&ld_avg, 1);

    test->set_load_avg(ld_avg);
}

Manageable::status_t
Test::ManagementMethod(uint32_t methodId, Args& args, std::string &errstr)
{
    cout << "Method Received: " << methodId << endl;
    int ret;

    switch (methodId) {
        case _qmf::TestObject::METHOD_CRYPT:
        {
            _qmf::ArgsTestObjectCrypt *ioArgs = (_qmf::ArgsTestObjectCrypt *) &args;
            const char *key;
            const char *salt;
            char *passwd;

            key = ioArgs->i_key.c_str();
            salt = ioArgs->i_salt.c_str();

            passwd = crypt(key, salt);

            if(passwd) {
                ioArgs->o_passwd = passwd;
            } else {
                std::ostringstream errmsg;
                errmsg << "Error calling crypt(): %s" << strerror(errno);
                errstr = errmsg.str();

                return STATUS_USER + ret;
            }
            return STATUS_OK;
        }
    }
}


