#!/bin/sh -e
# BINDIR is set to absolute path containing this script
a="/${0}"; a=${a%/*}; a=${a#/}; a=${a:-.}; BINDIR=`cd $a; pwd`
PATH=$BINDIR:$PATH
. $BINDIR/config
. $BINDIR/env

ARCH=`uname -m`

finish () {
  RET=$?

  pkill stress_agent
  wait

  echo See logfiles:
  for i in *.log; do echo $i; done | xargs echo "  " | fmt -w 10

  test $RET -eq 0 && echo SUCCESS || echo FAILURE $RET
  exit $RET
}

trap finish EXIT

confhash () {
  {
  uname -a
  xargs rpm -q < deps-mrg
  } | md5sum
}

if
  ! { test -r hash && confhash | diff - hash; }
then
  echo Cleaning up...
  $BINDIR/clean >/dev/null 2>&1
  confhash > hash
fi

pgrep qpidd >/dev/null || qpidd -d --auth=no --no-module-dir --log-to-file=qpidd.log -t

#tar xf movitto-qmf-20100503.tar.gz
(
cd $MOVITTO/stress_agent

if ! [ -x src/stress_agent ]
then
  echo Compiling stress_agent...
  { test -r Makefile || ./configure && make; } >$BINDIR/compile.log 2>&1
fi
)

echo -n Running stress agent with $STRESS_NUM objects...
{ $MOVITTO/stress_agent/src/stress_agent -n $STRESS_NUM & } >$BINDIR/stress_agent.log 2>&1
echo " background ($!)"

echo Waiting max ${SETTLE}s for agent to get initial object from broker...
sleep $SETTLE

echo Running console.rb with $TIMEOUT second timeout...
$BINDIR/timeout.sh $TIMEOUT \
  $MOVITTO/ruby/bin/console.rb -t testobject -s > $BINDIR/console.log 2>&1 \
  || exit $?

RET_OBJ_NUM=`grep "Object Retreived" console.log | wc -l`
RET_PASS_NUM=`grep "Generated password" console.log | wc -l`
test $RET_OBJ_NUM -eq $STRESS_NUM && test $RET_PASS_NUM -eq $STRESS_NUM || exit 125
